@@ -3,7 +3,7 @@ from __future__ import absolute_import, division, print_function
 
 import os
 
-from hypothesis import settings, Verbosity
+from hypothesis import Verbosity, settings
 
 settings.register_profile('ci', max_examples=1000)
 settings.register_profile('debug', verbosity=Verbosity.verbose)
