@@ -2,7 +2,7 @@
 from __future__ import absolute_import, division, print_function
 
 import pytest
-from hypothesis import assume, given
+from hypothesis import HealthCheck, assume, given, settings
 
 from parver import ParseError, Version
 
@@ -10,16 +10,19 @@ from .strategies import version_string, whitespace
 
 
 @given(whitespace, version_string(), whitespace)
+@settings(suppress_health_check=[HealthCheck.too_slow])
 def test_parse_hypothesis(prefix, version, suffix):
     Version.parse(prefix + version + suffix)
 
 
 @given(whitespace, version_string(strict=True), whitespace)
+@settings(suppress_health_check=[HealthCheck.too_slow])
 def test_parse_strict_hypothesis(prefix, version, suffix):
     Version.parse(prefix + version + suffix, strict=True)
 
 
 @given(version_string(strict=False))
+@settings(suppress_health_check=[HealthCheck.too_slow])
 def test_parse_strict_error(version):
     v = Version.parse(version)
 
@@ -34,6 +37,7 @@ def test_parse_strict_error(version):
 
 
 @given(version_string())
+@settings(suppress_health_check=[HealthCheck.too_slow])
 def test_roundtrip(version):
     assert str(Version.parse(version)) == version
 
